Tutorials
=========

End-to-end workflows are shown in the following set of tutorials:

.. toctree::
   :caption: Workflows
   :maxdepth: 2

   workflows/index

Further examples for the individual packages are available in these tutorials:

.. toctree::
   :caption: Packages
   :maxdepth: 2

   mammos-analysis/index
   mammos-dft/index
   mammos-entity/index
   mammos-mumag/index
   mammos-spindynamics/index
   mammos-units/index
